==> nocc-1.9.5.txz: usr/local/www/nocc/lang/bs.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: bs.php 2622 2014-08-06 14:50:40Z siebrand $
 */
/** Bosnian (bosanski)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author CERminator
 * @author KWiki
 */

$lang_locale = 'bs_BS.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Polje prijave je prazno';
$err_passwd_empty = 'Polje šifre je prazno';
$alt_delete = 'Obriši odabrane poruke';
$alt_delete_one = 'Obriši poruku';
$alt_new_msg = 'Nove poruke';
$alt_reply = 'Odgovori autoru';
$alt_reply_all = 'Odgovori sve';
$alt_forward = 'Naprijed';
$alt_next = 'Slijedeća';
$alt_prev = 'Prethodna';
$title_next_page = 'Slijedeća stranica';
$title_prev_page = 'Prethodna stranica';
$title_next_msg = 'Slijedeća poruka';
$title_prev_msg = 'Prethodna poruka';
$html_theme_label = 'Tema:';
$html_welcome = 'Dobro došli na %1$s';
$html_login = 'Prijava';
$html_user_label = 'Korisnik:';
$html_passwd_label = 'Šifra:';
$html_submit = 'Pošalji';
$html_help = 'Pomoć';
$html_server_label = 'Server:';
$html_wrong = 'Prijava ili šifra nisu tačni';
$html_retry = 'Ponovno pokušaj';
$html_remember = 'Zapamti postavke';
$html_lang_label = 'Jezik:';
$html_msgperpage_label = 'Poruka po stranici:';
$html_preferences = 'Postavke';
$html_full_name_label = 'Puno ime:';
$html_email_address_label = 'E-mail Adresa:';
$html_bccself = 'Bcc sebi';
$html_hide_addresses = 'Sakrij adrese';
$html_outlook_quoting = 'Citiranje u stilu Outlooka';
$html_reply_to = 'Odgovori';
$html_use_signature = 'Koristi potpis';
$html_signature = 'Potpis';
$html_signature_label = 'Potpis:';
$html_reply_leadin_label = 'Uvod odgovora:';
$html_prefs_updated = 'Postavke ažurirane';
$html_manage_folders_link = 'Upravljaj IMAP direktorijima';
$html_manage_filters_link = 'Upravljaj email filterima';
$html_use_graphical_smilies = 'Koristi grafičke smješke';
$html_sent_folder_label = 'Kopiraj poslane e-mailove u predviđeni direktorij:';
$html_trash_folder_label = 'Premjesti obrisane e-mailove u predviđeni direktorij:';
$html_colored_quotes = 'Obojeni citati';
$html_display_struct = 'Prikaži strukturisani tekst';
$html_send_html_mail = 'Pošalji mail u HTML formatu';
$html_folders = 'Direktoriji';
$html_folders_create_failed = 'Direktorijum nije mogao biti napravljen!';
$html_folders_sub_failed = 'Ne može se prijaviti u direktorijum!';
$html_folders_unsub_failed = 'Ne može se odjaviti iz direktorijuma!';
$html_folders_rename_failed = 'Direktorij nije moguće preimenovati!';
$html_folders_updated = 'Direktoriji ažurirani';
$html_folder_subscribe = 'Pretplati se na';
$html_folder_rename = 'Preimenuj';
$html_folder_create = 'Napravi novi direktorij pod imenom';
$html_folder_remove = 'Odustani od';
$html_folder_delete = 'Obriši';
$html_folder_to = 'za';
$html_filter_remove = 'Brisanje';
$html_filter_body = 'Tijelo poruke';
$html_filter_subject = 'Predmet poruke';
$html_filter_to = 'U polje';
$html_filter_cc = 'Polje cc';
$html_filter_from = 'Polje Od';
$html_filter_change_tip = 'Da biste promijenili filter jednostavno ga prepišite.';
$html_reapply_filters = 'Ponovna primjena svih filtera';
$html_filter_contains = 'sadrži';
$html_filter_name = 'Naziv filtera';
$html_filter_action = 'Akcija filtera';
$html_filter_moveto = 'Premjesti u';
$html_select_one = '--Odaberi jedan--';
$html_and = 'i';
$html_new_msg_in = 'Nove poruke u';
$html_or = 'ili';
$html_move = 'Premjesti';
$html_copy = 'Kopija';
$html_messages_to = 'odabrane poruke u';
$html_gotopage = 'Idi na stranicu';
$html_gotofolder = 'Idi u direktorijum';
$html_other_folders = 'Spisak direktorijuma';
$html_page = 'Stranica';
$html_of = 'od';
$html_view_header = 'Vidi zaglavlje';
$html_remove_header = 'Sakrij zaglavlje';
$html_inbox = 'Ulazni sandučić';
$html_new_msg = 'Piši';
$html_reply = 'Odgovor';
$html_reply_short = 'Odg:';
$html_reply_all = 'Odgovori sve';
$html_forward = 'Proslijediti';
$html_forward_short = 'Napr:';
$html_forward_info = 'Proslijeđene poruke će biti poslane kao prilog ovoj poruci.';
$html_delete = 'Brisanje';
$html_new = 'Nova';
$html_mark = 'Obriši';
$html_att_label = 'Prilog:';
$html_atts_label = 'Prilozi:';
$html_unknown = '[nepoznato]';
$html_part_x = 'Dio %s';
$html_attach = 'Dodaj';
$html_attach_forget = 'Morate dodati Vašu datoteku prije slanja poruke!';
$html_attach_delete = 'Ukloni odabrano';
$html_attach_none = 'Morate odabrati datoteku za dodavanje!';
$html_sort_by = 'Sortiranje po';
$html_sort = 'Sortiranje';
$html_from = 'Od';
$html_from_label = 'Od:';
$html_subject = 'Tema';
$html_subject_label = 'Tema:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent_label = 'Poslano:';
$html_wrote = 'napisao';
$html_size = 'Veličina';
$html_totalsize = 'Ukupna veličina';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bajta';
$html_filename = 'Ime datoteke';
$html_to = 'Za';
$html_to_label = 'Za:';
$html_cc = 'Kopija';
$html_cc_label = 'Kopija:';
$html_bcc_label = 'Skrivena kopija:';
$html_nosubject = 'Bez teme';
$html_send = 'Pošalji';
$html_cancel = 'Odustani';
$html_no_mail = 'Nema poruka.';
$html_logout = 'Odjava';
$html_msg = 'Poruka';
$html_msgs = 'Poruke';
$html_configuration = 'Ovaj server nije dobro postavljen!';
$html_priority = 'Prioritet';
$html_priority_label = 'Prioritet:';
$html_lowest = 'Najniži';
$html_low = 'Nizak';
$html_normal = 'Normalno';
$html_high = 'Visok';
$html_highest = 'Najviši';
$html_flagged = 'Označen';
$html_spam = 'Neželjena pošta';
$html_spam_warning = 'Ova poruka je klasificirana kao neželjena pošta.';
$html_receipt = 'Zahtjevaj potvrdu o prijemu';
$html_select = 'Odaberi';
$html_select_all = 'Obrni odabir';
$html_select_contacts = 'Odaberite kontakte';
$html_loading_image = 'Punim sliku';
$html_send_confirmed = 'Vaš e-mail je prihvaćen za dostavu';
$html_no_sendaction = 'Nije precizirana akcija. Pokušajte omogućiti JavaScript.';
$html_error_occurred = 'Desila se greška';
$html_prefs_file_error = 'Ne može se otvoriti datoteka postavki radi pisanja.';
$html_wrap = 'Broj znakova za kodiranje izlaznih poruka:';
$html_wrap_none = 'Bez lomljenja';
$html_usenet_separator = 'Usenet separator ("-- \n") prije potpisa';
$html_mark_as = 'Označi kao';
$html_read = 'pročitano';
$html_unread = 'nepročitano';
$html_encoding_label = 'Kodiranje znakova:';
$html_add = 'Dodaj';
$html_contacts = 'Kontakti od %1$s';
$html_modify = 'Izmijeni';
$html_back = 'Nazad';
$html_contact_add = 'Dodaj novi kontakt';
$html_contact_mod = 'Izmijeni kontakt';
$html_contact_first = 'Ime';
$html_contact_last = 'Prezime';
$html_contact_nick = 'Nadimak';
$html_contact_mail = 'E-mail';
$html_contact_list = 'Spisak kontakata od %1$s';
$html_contact_del = 'sa spiska kontakata';
$html_contact_count = 'Kontakti %1$d';
$html_contact_err1 = 'Najveći broj kontakata je "%1$d"';
$html_contact_err2 = 'Ne možete dodati novi kontakt';
$html_contact_err3 = 'Nemate pravo pristupa na spisak kontakata';
$html_contact_none = 'Nijedan kontakt nije pronađen.';
$html_del_msg = 'Obriši odabrane poruke ?';
$html_down_mail = 'Učitavanje';
$original_msg = '-- Prvobitna poruka --';
$to_empty = 'Polje \'Za\' ne smije biti prazno !';
$html_images_warning = 'Radi Vaše sigurnosti, slike iz vanjskih izvora nisu prikazane.';
$html_images_display = 'Prikaži slike';
$html_smtp_error_no_conn = 'Ne može se otvoriti SMTP veza';
$html_smtp_error_unexpected = 'Neočekivan SMTP odgovor:';
$lang_could_not_connect = 'nije moguće povezati se na server';
$lang_invalid_msg_num = 'Loš broj poruke';
$html_file_upload_attack = 'Moguć napad preko postavljanja datoteka';
$html_invalid_email_address = 'Nevaljana e-mail adresa';
$html_invalid_msg_per_page = 'Nevaljan broj poruka po stranici';
$html_invalid_wrap_msg = 'Nevaljana širina omota poruke';
$html_seperate_msg_win = 'Poruke u zaseban prozor';
$html_err_file_contacts = 'Ne može se otvoriti datoteka kontakata za pisanje.';
$html_session_file_error = 'Ne može se otvoriti datoteka sesije radi pisanja.';
$html_login_not_allowed = 'Ova prijava nije dopuštena za vezu.';
$lang_err_send_delay = 'Morate pričekati između dva e-maila (%1$d sekundi)';
$html_search = 'Pretraga';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/bs.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: bs.php 2656 2015-09-10 08:37:08Z siebrand $
 */
/** Bosnian (bosanski)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author CERminator
 * @author KWiki
 * @author Palapa
 * @author Srdjan m
 */

$lang_locale = 'bs_BS.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Polje prijave je prazno';
$err_passwd_empty = 'Polje šifre je prazno';
$alt_delete = 'Obriši odabrane poruke';
$alt_delete_one = 'Obriši poruku';
$alt_new_msg = 'Nove poruke';
$alt_reply = 'Odgovori autoru';
$alt_reply_all = 'Odgovori sve';
$alt_forward = 'Naprijed';
$alt_next = 'Slijedeća';
$alt_prev = 'Prethodna';
$title_next_page = 'Slijedeća stranica';
$title_prev_page = 'Prethodna stranica';
$title_next_msg = 'Slijedeća poruka';
$title_prev_msg = 'Prethodna poruka';
$html_theme_label = 'Tema:';
$html_welcome = 'Dobro došli na %1$s';
$html_login = 'Prijava';
$html_user_label = 'Korisnik:';
$html_passwd_label = 'Šifra:';
$html_submit = 'Pošalji';
$html_help = 'Pomoć';
$html_server_label = 'Server:';
$html_wrong = 'Prijava ili šifra nisu tačni';
$html_retry = 'Ponovno pokušaj';
$html_remember = 'Zapamti postavke';
$html_lang_label = 'Jezik:';
$html_msgperpage_label = 'Poruka po stranici:';
$html_preferences = 'Postavke';
$html_full_name_label = 'Puno ime:';
$html_email_address_label = 'Adresa e-pošte:';
$html_bccself = 'Bcc sebi';
$html_hide_addresses = 'Sakrij adrese';
$html_outlook_quoting = 'Citiranje u stilu Outlooka';
$html_reply_to = 'Odgovori';
$html_reply_to_label = 'Odgovori:';
$html_use_signature = 'Koristi potpis';
$html_signature = 'Potpis';
$html_signature_label = 'Potpis:';
$html_reply_leadin_label = 'Uvod odgovora:';
$html_prefs_updated = 'Postavke ažurirane';
$html_manage_folders_link = 'Upravljaj IMAP direktorijima';
$html_manage_filters_link = 'Upravljaj email filterima';
$html_use_graphical_smilies = 'Koristi grafičke smješke';
$html_sent_folder_label = 'Kopiraj poslane e-mailove u predviđeni direktorij:';
$html_trash_folder_label = 'Premjesti obrisane e-mailove u predviđeni direktorij:';
$html_colored_quotes = 'Obojeni citati';
$html_display_struct = 'Prikaži strukturisani tekst';
$html_send_html_mail = 'Pošalji mail u HTML formatu';
$html_folders = 'Direktoriji';
$html_folders_create_failed = 'Direktorijum nije mogao biti napravljen!';
$html_folders_sub_failed = 'Ne može se prijaviti u direktorijum!';
$html_folders_unsub_failed = 'Ne može se odjaviti iz direktorijuma!';
$html_folders_rename_failed = 'Direktorij nije moguće preimenovati!';
$html_folders_updated = 'Direktoriji ažurirani';
$html_folder_subscribe = 'Pretplati se na';
$html_folder_rename = 'Preimenuj';
$html_folder_create = 'Napravi novi direktorij pod imenom';
$html_folder_remove = 'Odustani od';
$html_folder_delete = 'Obriši';
$html_folder_to = 'za';
$html_filter_remove = 'Brisanje';
$html_filter_body = 'Tijelo poruke';
$html_filter_subject = 'Predmet poruke';
$html_filter_to = 'U polje';
$html_filter_cc = 'Polje cc';
$html_filter_from = 'Polje Od';
$html_filter_change_tip = 'Da biste promijenili filter jednostavno ga prepišite.';
$html_reapply_filters = 'Ponovna primjena svih filtera';
$html_filter_contains = 'sadrži';
$html_filter_name = 'Naziv filtera';
$html_filter_action = 'Akcija filtera';
$html_filter_moveto = 'Premjesti u';
$html_select_one = '--Odaberi jedan--';
$html_and = 'i';
$html_new_msg_in = 'Nove poruke u';
$html_or = 'ili';
$html_move = 'Premjesti';
$html_copy = 'Kopija';
$html_messages_to = 'odabrane poruke u';
$html_gotopage = 'Idi na stranicu';
$html_gotofolder = 'Idi u direktorijum';
$html_other_folders = 'Spisak direktorijuma';
$html_page = 'Stranica';
$html_of = 'od';
$html_view_header = 'Vidi zaglavlje';
$html_remove_header = 'Sakrij zaglavlje';
$html_inbox = 'Ulazni sandučić';
$html_new_msg = 'Piši';
$html_reply = 'Odgovor';
$html_reply_short = 'Odg:';
$html_reply_all = 'Odgovori sve';
$html_forward = 'Proslijediti';
$html_forward_short = 'Napr:';
$html_forward_info = 'Proslijeđene poruke će biti poslane kao prilog ovoj poruci.';
$html_delete = 'Brisanje';
$html_new = 'Nova';
$html_mark = 'Obriši';
$html_att_label = 'Prilog:';
$html_atts_label = 'Prilozi:';
$html_unknown = '[nepoznato]';
$html_part_x = 'Dio %s';
$html_attach = 'Dodaj';
$html_attach_forget = 'Morate dodati Vašu datoteku prije slanja poruke!';
$html_attach_delete = 'Ukloni odabrano';
$html_attach_none = 'Morate odabrati datoteku za dodavanje!';
$html_sort_by = 'Sortiranje po';
$html_sort = 'Sortiranje';
$html_from = 'Od';
$html_from_label = 'Od:';
$html_subject = 'Tema';
$html_subject_label = 'Tema:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent_label = 'Poslano:';
$html_wrote = 'napisao';
$html_size = 'Veličina';
$html_totalsize = 'Ukupna veličina';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bajta';
$html_filename = 'Ime datoteke';
$html_to = 'Za';
$html_to_label = 'Za:';
$html_cc = 'Kopija';
$html_cc_label = 'Kopija:';
$html_bcc_label = 'Skrivena kopija:';
$html_nosubject = 'Bez teme';
$html_send = 'Pošalji';
$html_cancel = 'Odustani';
$html_no_mail = 'Nema poruka.';
$html_logout = 'Odjava';
$html_msg = 'Poruka';
$html_msgs = 'Poruke';
$html_configuration = 'Ovaj server nije dobro postavljen!';
$html_priority = 'Prioritet';
$html_priority_label = 'Prioritet:';
$html_lowest = 'Najniži';
$html_low = 'Nizak';
$html_normal = 'Normalno';
$html_high = 'Visok';
$html_highest = 'Najviši';
$html_flagged = 'Označen';
$html_spam = 'Neželjena pošta';
$html_spam_warning = 'Ova poruka je klasificirana kao neželjena pošta.';
$html_receipt = 'Zahtjevaj potvrdu o prijemu';
$html_select = 'Odaberi';
$html_select_all = 'Obrni odabir';
$html_select_contacts = 'Odaberite kontakte';
$html_loading_image = 'Punim sliku';
$html_send_confirmed = 'Vaš e-mail je prihvaćen za dostavu';
$html_no_sendaction = 'Nije precizirana akcija. Pokušajte omogućiti JavaScript.';
$html_error_occurred = 'Desila se greška';
$html_prefs_file_error = 'Ne može se otvoriti datoteka postavki radi pisanja.';
$html_wrap = 'Broj znakova za kodiranje izlaznih poruka:';
$html_wrap_none = 'Bez lomljenja';
$html_usenet_separator = 'Usenet separator ("-- \n") prije potpisa';
$html_mark_as = 'Označi kao';
$html_read = 'pročitano';
$html_unread = 'nepročitano';
$html_encoding_label = 'Kodiranje znakova:';
$html_add = 'Dodaj';
$html_contacts = 'Kontakti od %1$s';
$html_modify = 'Izmijeni';
$html_back = 'Nazad';
$html_contact_add = 'Dodaj novi kontakt';
$html_contact_mod = 'Izmijeni kontakt';
$html_contact_first = 'Ime';
$html_contact_last = 'Prezime';
$html_contact_nick = 'Nadimak';
$html_contact_mail = 'E-mail';
$html_contact_list = 'Spisak kontakata od %1$s';
$html_contact_del = 'sa spiska kontakata';
$html_contact_count = 'Kontakti %1$d';
$html_contact_err1 = 'Najveći broj kontakata je "%1$d"';
$html_contact_err2 = 'Ne možete dodati novi kontakt';
$html_contact_err3 = 'Nemate pravo pristupa na spisak kontakata';
$html_contact_none = 'Nijedan kontakt nije pronađen.';
$html_del_msg = 'Obriši odabrane poruke ?';
$html_down_mail = 'Učitavanje';
$original_msg = '-- Prvobitna poruka --';
$to_empty = 'Polje \'Za\' ne smije biti prazno !';
$html_images_warning = 'Radi Vaše sigurnosti, slike iz vanjskih izvora nisu prikazane.';
$html_images_display = 'Prikaži slike';
$html_smtp_error_no_conn = 'Ne može se otvoriti SMTP veza';
$html_smtp_error_unexpected = 'Neočekivan SMTP odgovor:';
$lang_could_not_connect = 'nije moguće povezati se na server';
$lang_invalid_msg_num = 'Loš broj poruke';
$html_file_upload_attack = 'Moguć napad preko postavljanja datoteka';
$html_invalid_email_address = 'Nevaljana e-mail adresa';
$html_invalid_msg_per_page = 'Nevaljan broj poruka po stranici';
$html_invalid_wrap_msg = 'Nevaljana širina omota poruke';
$html_seperate_msg_win = 'Poruke u zaseban prozor';
$html_err_file_contacts = 'Ne može se otvoriti datoteka kontakata za pisanje.';
$html_session_file_error = 'Ne može se otvoriti datoteka sesije radi pisanja.';
$html_login_not_allowed = 'Ova prijava nije dopuštena za vezu.';
$lang_err_send_delay = 'Morate pričekati između dva e-maila (%1$d sekundi)';
$html_search = 'Pretraga';
$html_new_session = 'Sljedeća sesija';
